@@ -3,7 +3,7 @@ use Object::Pad;
 
 package OpenTelemetry::Trace::Tracer;
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 use Log::Any;
 my $logger = Log::Any->get_logger( category => 'OpenTelemetry' );
@@ -51,7 +51,13 @@ class OpenTelemetry::Trace::Tracer {
         }
         catch ($e) {
             $span->record_exception($e);
-            $span->set_status( SPAN_STATUS_ERROR, "$e" );
+
+            my ($message) = split /\n/, "$e", 2;
+
+            $span->set_status(
+                SPAN_STATUS_ERROR, $message =~ s/ at \S+ line \d+\.$//r
+            );
+
             die $e;
         }
         finally {
